@@ -61,10 +61,10 @@ class Constants(BaseConstants):
     P1_Acc_ArgBestToken = 2
     # </editor-fold>
     # <editor-fold desc="Zeiten (in Minuten">
-    ChatTime_Ack = 6  # Todo: Check if time is correct. Should be 6 minutes.
+    ChatTime_Ack = 6  
     ChatTime_Ack_Sec = ChatTime_Ack * 60
-    ChatTime_Distribution = 5  # Formerly known as ChatTime_Verteilung #Todo: Check if time is correct. Should be 5 minutes.
-    ChatTime_DistributionCorr = 1  # Formerly known as ChatTime_VerteilungKorr #Todo: Check if time is correct. Should be 1 minute.
+    ChatTime_Distribution = 5  # Formerly known as ChatTime_Verteilung 
+    ChatTime_DistributionCorr = 1  # Formerly known as ChatTime_VerteilungKorr
     ChatTime_DistributionCorrSek = ChatTime_DistributionCorr * 60  # Formerly known as ChatTime_VerteilungKorrSek
     # </editor-fold>
 
