@@ -1,5 +1,8 @@
 class Constants(BaseConstants):
     min_payoffAB = (float(1.0)) + (float(1.1)) + (float(1.2))  # 3.3
+    
+class Subsession(BaseSubsession):
+    pass
 
 class Player(BasePlayer):
     min_payoffAB = models.FloatField(
@@ -13,4 +16,4 @@ class Group(BaseGroup):
 
     variable2 = models.FloatField(
         doc = "variable variable2",
-        max = ((1.0)) + ((1.1)) + ((1.2)) )
\ No newline at end of file
+        max = ((1.0)) + ((1.1)) + ((1.2)) )
